@@ -4,8 +4,7 @@ use Cwd qw(realpath);
 use Code::TidyAll::Config::INI::Reader;
 use Code::TidyAll::Cache;
 use Code::TidyAll::CacheModel;
-use Code::TidyAll::Util
-    qw(abs2rel basename can_load dirname dump_one_line mkpath read_dir rel2abs tempdir_simple uniq);
+use Code::TidyAll::Util qw(basename can_load dirname dump_one_line mkpath read_dir rel2abs);
 use Code::TidyAll::Result;
 use Date::Format;
 use Digest::SHA qw(sha1_hex);
@@ -19,7 +18,7 @@ use Try::Tiny;
 use strict;
 use warnings;
 
-our $VERSION = '0.31';
+our $VERSION = '0.34';
 
 sub default_conf_names { ( 'tidyall.ini', '.tidyallrc' ) }
 
@@ -95,10 +94,11 @@ sub _build_plugin_objects {
     my @plugin_objects = map { $self->_load_plugin( $_, $self->plugins->{$_} ) }
         keys( %{ $self->plugins_for_mode } );
 
-    # Sort tidiers before validators, then alphabetical
-    #
-    return [ sort { ( $a->is_validator <=> $b->is_validator ) || ( $a->name cmp $b->name ) }
-            @plugin_objects ];
+    # Sort tidiers by weight (by default validators have a weight of 60 and non-
+    # validators a weight of 50 meaning non-validators normally go first), then
+    # alphabetical
+    # TODO: These should probably sort in a consistent way independent of locale
+    return [ sort { ( $a->weight <=> $b->weight ) || ( $a->name cmp $b->name ) } @plugin_objects ];
 }
 
 sub BUILD {
@@ -295,10 +295,20 @@ sub process_source {
     my $new_contents = my $orig_contents = $contents;
     my $plugin;
 
+    if ( $self->verbose ) {
+        $self->msg("[applying the following plugins: @plugins]");
+    }
+
+    my @diffs;
     try {
         foreach my $method (qw(preprocess_source process_source_or_file postprocess_source)) {
             foreach $plugin (@plugins) {
-                $new_contents = $plugin->$method( $new_contents, $basename );
+                my $diff;
+                ( $new_contents, $diff )
+                    = $plugin->$method( $new_contents, $basename, $self->check_only );
+                if ($diff) {
+                    push @diffs, [ $plugin->name, $diff ];
+                }
             }
         }
     }
@@ -311,11 +321,11 @@ sub process_source {
     my $was_tidied = !$error && ( $new_contents ne $orig_contents );
     if ( $was_tidied && $self->check_only ) {
         $error = "*** needs tidying";
-        my $diff = q{};
-        foreach $plugin (@plugins) {
-            $diff = $plugin->diff( $diff, $orig_contents, $new_contents, $path );
+        foreach my $diff (@diffs) {
+            $error .= "\n\n";
+            $error .= "$diff->[0] made the following change:\n$diff->[1]";
         }
-        $error .= "\n\n" . $diff if length $diff;
+        $error .= "\n\n" if @diffs;
         undef $was_tidied;
     }
 
@@ -535,7 +545,7 @@ Code::TidyAll - Engine for tidyall, your all-in-one code tidier and validator
 
 =head1 VERSION
 
-version 0.31
+version 0.34
 
 =head1 SYNOPSIS
 
@@ -616,6 +626,10 @@ by default.
 
 =item check_only
 
+If this is true, then we simply check that files pass validation steps and that
+tidying them does not change the file. Any changes from tidying are not
+actually written back to the file.
+
 =item no_cleanup
 
 A boolean indicating if we should skip cleaning temporary files or not.
