@@ -1,13 +1,14 @@
 package Code::TidyAll::Git::Util;
 
 use Cwd qw(realpath);
-use Code::TidyAll::Util qw(pushd uniq);
+use Code::TidyAll::Util qw(pushd);
 use IPC::System::Simple qw(capturex);
+use List::MoreUtils qw(uniq);
 use strict;
 use warnings;
 use base qw(Exporter);
 
-our $VERSION = '0.31';
+our $VERSION = '0.34';
 
 our @EXPORT_OK = qw(git_uncommitted_files);
 
