@@ -1,15 +1,15 @@
 package Code::TidyAll::Plugin::PodSpell;
 
-use Code::TidyAll::Util qw(basename uniq);
 use Capture::Tiny qw();
 use IPC::System::Simple qw();
 use IPC::Run3;
+use List::MoreUtils qw(uniq);
 use Pod::Spell;
 use Moo;
 use Text::ParseWords qw(shellwords);
 extends 'Code::TidyAll::Plugin';
 
-our $VERSION = '0.31';
+our $VERSION = '0.34';
 
 has 'ispell_argv' => ( is => 'ro', default => q{} );
 has 'ispell_cmd'  => ( is => 'ro', default => 'ispell' );
@@ -58,7 +58,7 @@ Code::TidyAll::Plugin::PodSpell - Use Pod::Spell + ispell with tidyall
 
 =head1 VERSION
 
-version 0.31
+version 0.34
 
 =head1 SYNOPSIS
 
