@@ -2,13 +2,13 @@ package Code::TidyAll::SVN::Precommit;
 
 use Capture::Tiny qw(capture_stdout capture_stderr);
 use Code::TidyAll;
-use Code::TidyAll::Util qw(basename dirname mkpath realpath tempdir_simple write_file);
+use Code::TidyAll::Util qw(basename dirname mkpath tempdir_simple write_file);
 use Log::Any qw($log);
 use Moo;
 use SVN::Look;
 use Try::Tiny;
 
-our $VERSION = '0.32';
+our $VERSION = '0.34';
 
 # Public
 has 'conf_name'                => ( is => 'ro' );
@@ -175,7 +175,7 @@ to be tidyall'd
 
 =head1 VERSION
 
-version 0.32
+version 0.34
 
 =head1 SYNOPSIS
 
