@@ -4,19 +4,18 @@ use Cwd qw(realpath);
 use Data::Dumper;
 use File::Basename;
 use File::Path;
-use File::Spec::Functions qw(abs2rel rel2abs);
+use File::Spec::Functions qw(rel2abs);
 use File::Temp qw(tempdir);
 use Guard;
-use List::MoreUtils qw(uniq);
 use Try::Tiny;
 use strict;
 use warnings;
 use base qw(Exporter);
 
-our $VERSION = '0.31';
+our $VERSION = '0.34';
 
 our @EXPORT_OK
-    = qw(abs2rel basename can_load dirname dump_one_line mkpath pushd read_dir realpath rel2abs tempdir_simple trim uniq);
+    = qw(basename can_load dirname dump_one_line mkpath pushd read_dir realpath rel2abs tempdir_simple);
 
 sub can_load {
 
@@ -61,12 +60,6 @@ sub pushd {
     return guard { chdir($cwd) };
 }
 
-sub trim {
-    my ($str) = @_;
-    for ($str) { s/^\s+//; s/\s+$// }
-    return $str;
-}
-
 sub read_dir {
     my ($dir) = @_;
     opendir( my $dirh, $dir ) or die "could not open $dir: $!";
